@@ -26,6 +26,7 @@ import mimetypes
 import operator
 import os.path
 import re
+import string
 import sys
 
 from turberfield.dialogue.directives import Condition as ConditionDirective
@@ -98,7 +99,7 @@ class Model(docutils.nodes.GenericNodeVisitor):
             )
             ref, dot, attr = getter["arguments"][0].partition(".")
             entity = self.get_entity(ref)
-            rv = str(operator.attrgetter(attr)(entity.persona))
+            rv = str(operator.attrgetter(attr)(entity.persona)).strip()
         except (AttributeError, KeyError, IndexError, StopIteration) as e:
             self.log.warning("Argument has bad substitution ref {0}".format(matchObj.group(1)))
             rv = ""
@@ -110,44 +111,9 @@ class Model(docutils.nodes.GenericNodeVisitor):
     def default_departure(self, node):
         pass
 
-    def visit_section(self, node):
-        self.section_level += 1
-
-    def depart_field(self, node):
-        if self.section_level == 0:
-            data = tuple(
-                ("\n".join([" ".join(getattr(p, "text", [p.rawsource])) for p in f.children])
-                 if f.tagname == "field_body" else f.rawsource).strip()
-                for f in node.children
-            )
-            if data not in self.metadata:
-                self.log.debug(data)
-                self.metadata.append(data)
-
-    def depart_section(self, node):
-        self.section_level -= 1
-
-    def visit_Setter(self, node):
-        ref, attr = node["arguments"][0].split(".")
-        entity = self.get_entity(ref)
-        s = re.compile("\|(\w+)\|").sub(self.substitute_property, node["arguments"][1])
-        val = int(s) if s.isdigit() else node.string_import(s)
-        self.shots[-1].items.append(Model.Property(self.speaker, entity.persona, attr, val))
-
-    def visit_Definition(self, node):
-        state = node.string_import(node["arguments"][0])
-        subj = self.get_entity(node["options"].get("subject"))
-        obj = self.get_entity(node["options"].get("object"))
-        self.memory = Model.Memory(
-            subj and subj.persona, obj and obj.persona, state, None, None
-        )
-
-    def visit_Evaluation(self, node):
-        ref, attr = node["arguments"][0].split(".")
-        entity = self.get_entity(ref)
-        s = re.compile("\|(\w+)\|").sub(self.substitute_property, node["arguments"][1])
-        val = int(s) if s.isdigit() else node.string_import(s)
-        self.shots[-1].items.append(Model.Condition(entity.persona, attr, val, operator.eq))
+    def visit_citation_reference(self, node):
+        entity = self.get_entity(node.attributes["refname"])
+        self.speaker = entity.persona
 
     def visit_Cue(self, node):
         subref_re = re.compile("\|(\w+)\|")
@@ -170,6 +136,122 @@ class Model(docutils.nodes.GenericNodeVisitor):
         if item is not None:
             self.shots[-1].items.append(item)
 
+    def visit_Definition(self, node):
+        state = node.string_import(node["arguments"][0])
+        subj = self.get_entity(node["options"].get("subject"))
+        obj = self.get_entity(node["options"].get("object"))
+        self.memory = Model.Memory(
+            subj and subj.persona, obj and obj.persona, state, None, None
+        )
+
+    def visit_emphasis(self, node):
+        text = node.astext()
+        self.text.append(text.lstrip() if self.text and self.text[-1].endswith(tuple(string.whitespace)) else text)
+        self.html.append('<em class="text">{0}</em>'.format(text))
+
+    def visit_Evaluation(self, node):
+        ref, attr = node["arguments"][0].split(".")
+        entity = self.get_entity(ref)
+        s = re.compile("\|(\w+)\|").sub(self.substitute_property, node["arguments"][1])
+        val = int(s) if s.isdigit() else node.string_import(s)
+        self.shots[-1].items.append(Model.Condition(entity.persona, attr, val, operator.eq))
+
+    def depart_field(self, node):
+        if self.section_level == 0:
+            data = tuple(
+                ("\n".join([" ".join(getattr(p, "text", [p.rawsource])) for p in f.children])
+                 if f.tagname == "field_body" else f.rawsource).strip()
+                for f in node.children
+            )
+            if data not in self.metadata:
+                self.log.debug(data)
+                self.metadata.append(data)
+
+    def visit_literal(self, node):
+        text = node.astext()
+        self.text.append(text.lstrip() if self.text and self.text[-1].endswith(tuple(string.whitespace)) else text)
+        self.html.append('<pre class="text">{0}</pre>'.format(text))
+
+    def visit_paragraph(self, node):
+        self.text = []
+        self.html = []
+
+    def depart_paragraph(self, node):
+        if self.memory:
+            self.shots[-1].items.append(
+                self.memory._replace(text="".join(self.text), html="\n".join(self.html))
+            )
+            self.memory = None
+        elif self.section_level == 0:
+            node.text = self.text
+            node.html = self.html
+        elif (self.text or self.html) and self.section_level == 2:
+            self.shots[-1].items.append(
+                Model.Line(self.speaker, "".join(self.text), "\n".join(self.html))
+            )
+            del self.text
+            del self.html
+
+    def visit_reference(self, node):
+        ref_id = self.document.nameids.get(node.get("refname", None), None)
+        if ref_id:
+            target = self.document.ids[ref_id]
+            ref_uri = target["refuri"]
+        else:
+            ref_uri = node["refuri"]
+        text = node.astext()
+        self.text.append(text.lstrip() if self.text and self.text[-1].endswith(tuple(string.whitespace)) else text)
+        self.html.append('<a href="{0}">{1}</a>'.format(ref_uri, text))
+
+    def visit_section(self, node):
+        self.section_level += 1
+
+    def depart_section(self, node):
+        self.section_level -= 1
+
+    def visit_Setter(self, node):
+        ref, attr = node["arguments"][0].split(".")
+        entity = self.get_entity(ref)
+        s = re.compile("\|(\w+)\|").sub(self.substitute_property, node["arguments"][1])
+        val = int(s) if s.isdigit() else node.string_import(s)
+        self.shots[-1].items.append(Model.Property(self.speaker, entity.persona, attr, val))
+
+    def visit_strong(self, node):
+        text = node.astext()
+        self.text.append(text.lstrip() if self.text and self.text[-1].endswith(tuple(string.whitespace)) else text)
+        self.html.append('<strong class="text">{0}</strong>'.format(text))
+
+    def visit_substitution_reference(self, node):
+        try:
+            defn = self.document.substitution_defs[node.attributes["refname"]]
+        except KeyError:
+            self.log.warning(
+                "Bad substitution ref before line {0}: {1.rawsource}".format(
+                    node.line, node
+                )
+            )
+            raise
+        for tgt in defn.children:
+            if isinstance(tgt, PropertyDirective.Getter):
+                ref, dot, attr = tgt["arguments"][0].partition(".")
+                entity = self.get_entity(ref)
+                if entity is None:
+                    obj = Pathfinder.string_import(
+                        tgt["arguments"][0], relative=False, sep="."
+                    )
+                    self.text.append(str(obj).strip())
+                    self.html.append(str(obj).strip())
+                elif getattr(entity, "persona", None) is not None:
+                    val = operator.attrgetter(attr)(entity.persona)
+                    self.text.append(val.strip())
+                    self.html.append('<span class="ref">{0}</span>'.format(val))
+
+    def visit_Text(self, node):
+        if isinstance(node.parent, docutils.nodes.paragraph):
+            text = node.astext()
+            self.text.append(text.lstrip() if self.text and self.text[-1].endswith(tuple(string.whitespace)) else text)
+            self.html.append('<span class="text">{0}</span>'.format(text))
+
     def visit_title(self, node):
         self.log.debug(self.section_level)
         if isinstance(node.parent, docutils.nodes.section):
@@ -181,60 +263,6 @@ class Model(docutils.nodes.GenericNodeVisitor):
                     self.scenes[-1],
                     []))
 
-    def visit_paragraph(self, node):
-        text = []
-        html = []
-        for c in node.children:
-            if isinstance(c, docutils.nodes.substitution_reference):
-                try:
-                    defn = self.document.substitution_defs[c.attributes["refname"]]
-                except KeyError:
-                    self.log.warning(
-                        "Bad substitution ref before line {0}: {1.rawsource}".format(
-                            node.line, c
-                        )
-                    )
-                    raise
-                for tgt in defn.children:
-                    if isinstance(tgt, PropertyDirective.Getter):
-                        ref, dot, attr = tgt["arguments"][0].partition(".")
-                        entity = self.get_entity(ref)
-                        if entity is None:
-                            obj = Pathfinder.string_import(
-                                tgt["arguments"][0], relative=False, sep="."
-                            )
-                            text.append(str(obj))
-                            html.append(str(obj))
-                        elif getattr(entity, "persona", None) is not None:
-                            val = operator.attrgetter(attr)(entity.persona)
-                            text.append(val)
-                            html.append('<span class="ref">{0}</span>'.format(val))
-            elif isinstance(c, docutils.nodes.strong):
-                text.append(c.rawsource)
-                html.append(
-                    '<strong class="text">{0}</strong>'.format(c.rawsource.replace("*", ""))
-                )
-            elif isinstance(c, docutils.nodes.Text):
-                text.append(c.rawsource)
-                html.append('<span class="text">{0}</span>'.format(c.rawsource))
-
-        if self.memory:
-            self.shots[-1].items.append(
-                self.memory._replace(text=" ".join(text), html="\n".join(html))
-            )
-            self.memory = None
-        elif self.section_level == 0:
-            node.text = text
-            node.html = html
-        elif (text or html) and self.section_level == 2:
-            self.shots[-1].items.append(
-                Model.Line(self.speaker, " ".join(text), "\n".join(html))
-            )
-
-    def visit_citation_reference(self, node):
-        entity = self.get_entity(node.attributes["refname"])
-        self.speaker = entity.persona
-
 class SceneScript:
     """Gives access to a Turberfield scene script (.rst) file.
 
