@@ -64,7 +64,7 @@ class PropertyDirectiveTests(unittest.TestCase):
         shot, line = next(iter(model))
         self.assertEqual("scene", shot.scene)
         self.assertEqual("shot", shot.name)
-        self.assertEqual("Hi, I'm  William .", line.text)
+        self.assertEqual("Hi, I'm William.", line.text)
 
     def test_property_getter_fields(self):
         content = textwrap.dedent("""
@@ -106,8 +106,8 @@ class PropertyDirectiveTests(unittest.TestCase):
         self.assertEqual("scene", shot.scene)
         self.assertEqual("shot", shot.name)
         self.assertIn(line.text, (
-            "You can call me  Fuzzer .",
-            "You can call me  Q.A ."))
+            "You can call me Fuzzer.",
+            "You can call me Q.A."))
 
     def test_property_setter_enum(self):
         content = textwrap.dedent("""
@@ -667,3 +667,78 @@ class SelectTests(unittest.TestCase):
         rv = list(script.select(ensemble, roles=2).values())
         self.assertEqual(ensemble[0], rv[0])
         self.assertEqual(ensemble[0], rv[1])
+
+
+class RstFeatureTests(unittest.TestCase):
+
+    def test_markup_body_text(self):
+        content = textwrap.dedent("""
+            Markup
+            ======
+
+            Emphasis
+            --------
+
+            I *keep* telling you.
+
+            I :emphasis:`keep` telling you.
+
+            Strong
+            ------
+
+            I **keep** telling you.
+
+            I :strong:`keep` telling you.
+
+            Preformat
+            ---------
+
+            I ``keep`` telling you.
+
+            I :literal:`keep` telling you.
+        """)
+        script = SceneScript("inline", doc=SceneScript.read(content))
+        model = script.run()
+        for shot in model.shots:
+            with self.subTest(shot_name=shot.name):
+                self.assertTrue(all("keep" in line.text for line in shot.items))
+                self.assertFalse(any("  " in line.text for line in shot.items), shot)
+                if shot.name.startswith("em"):
+                    self.assertTrue(all('<em class="text">' in line.html for line in shot.items)) 
+                    self.assertTrue(all("</em>" in line.html for line in shot.items)) 
+                elif shot.name.startswith("strong"):
+                    self.assertTrue(all('<strong class="text">' in line.html for line in shot.items)) 
+                    self.assertTrue(all("</strong>" in line.html for line in shot.items)) 
+                elif shot.name.startswith("pre"):
+                    self.assertTrue(all('<pre class="text">' in line.html for line in shot.items)) 
+                    self.assertTrue(all("</pre>" in line.html for line in shot.items))
+
+    def test_hyperlink_body_text(self):
+        content = textwrap.dedent("""
+            Hyperlinks
+            ==========
+
+            Standalone
+            ----------
+
+            See http://www.python.org for info.
+
+            Embedded
+            --------
+
+            See the `Python site <http://www.python.org>`_ for info.
+
+            Named
+            -----
+
+            See the `Python home page`_ for info.
+
+            .. _Python home page: http://www.python.org
+
+        """)
+        script = SceneScript("inline", doc=SceneScript.read(content))
+        model = script.run()
+        for shot in model.shots:
+            with self.subTest(shot_name=shot.name):
+                self.assertFalse(any("  " in line.text for line in shot.items))
+                self.assertTrue(all('<a href="http://www.python.org">' in i.html for i in shot.items), shot)
